Crate dam_lev

Crate dam_lev 

Enums

Mutation
Represents a way of mutating a sequence.

Functions

diff
Determine a minimal sequence of mutations that will transform one sequence into another.
diff_with_compare
Does the same as diff but the elements of the sequences are compared using a user-provided function.