Enums
- Mutation
- Represents a way of mutating a sequence.
Functions
- diff
- Determine a minimal sequence of mutations that will transform one sequence into another.
- diff_
with_ compare - Does the same as
diffbut the elements of the sequences are compared using a user-provided function.